Import-Module FailoverClusters


Function Get-CSVFreeSpace {
Param(
[Parameter(Mandatory=$true, HelpMessage="Threshold Percentage")][int] $Threshold,
[Parameter(Mandatory=$true, HelpMessage="Mark Mail as High Priority Percentage")][int] $HIGHPRIO,
[Parameter(Mandatory=$false, HelpMessage="Log to screen?")][boolean] $Logging,
[Parameter(Mandatory=$false, HelpMessage="Mail Log?")][boolean] $MailLog,
[Parameter(Mandatory=$false, HelpMessage="Mail recipient")][string] $Mailto,
[Parameter(Mandatory=$false, HelpMessage="Mail sender")][string] $From,
[Parameter(Mandatory=$false, HelpMessage="Mail Subject")][string] $Subject,
[Parameter(Mandatory=$false, HelpMessage="SMTP Server")][string] $Smtpserver,
[Parameter(Mandatory=$false, HelpMessage="List all CSV's")][boolean] $CompleteLog,
[Parameter(Mandatory=$false, HelpMessage="Exceptions to skip Normal Threshold, but included in HIGH Prio")][array] $Exclusions

)

if ($MailLog)
  {
  if ($Mailto -eq "") { $quit = $true }
  if ($From -eq "") { $quit = $true }
  if ($Subject -eq "") { $quit = $true }
  if ($Smtpserver -eq "") { $quit = $true }

  if ($quit) 
    { 
    write-host -f red "When using MailLog 'Mailto, From, Subject and Smtpserver' are required" 
  return 
    }
}

$objs = @()
$objThreshold = @()

$HighPrioFlag = "normal"
$SendMail = $false

if ($CompleteLog) { $SendMail = $true }

$Completetable = ""
$Completetable += "<p><b>All CSV's</b><br><table>"
$Completetable += "<tr><td class='bottomborder'>Name</td><td class='bottomborder'>Path</td><td class='bottomborder'>Size (GB)</td><td class='bottomborder'>FreeSpace (GB)</td><td class='bottomborder'>UsedSpace (GB)</td><td class='bottomborder'>PercentFree</td></tr>"


$Threstable = "<style>.bottomborder {border-bottom: 1px solid black;} .leftborder {border-left: 1px solid black;} .red {color: #ff0000;} .green {color: #00ff00;} .orange {color: #ff8000;}</style>"
$Threstable += "<b>All CSV's under a Threshold of " + $Threshold + "%</b><br><table>"
$Threstable += "<tr><td class='bottomborder'>Name</td><td class='bottomborder'>Path</td><td class='bottomborder'>Size (GB)</td><td class='bottomborder'>FreeSpace (GB)</td><td class='bottomborder'>UsedSpace (GB)</td><td class='bottomborder'>PercentFree</td></tr>"

$csvs = Get-ClusterSharedVolume
foreach ( $csv in $csvs )
{
   $csvinfos = $csv | select -Property Name -ExpandProperty SharedVolumeInfo
   foreach ( $csvinfo in $csvinfos )
   {
      $obj = New-Object PSObject -Property @{
         Name        = $csv.Name
         Path        = $csvinfo.FriendlyVolumeName
         Size        = $csvinfo.Partition.Size
         FreeSpace   = $csvinfo.Partition.FreeSpace
         UsedSpace   = $csvinfo.Partition.UsedSpace
         PercentFree = $csvinfo.Partition.PercentFree
      }
      $objs += $obj
      $Completetable += "<tr><td>" + $obj.Name + "</td><td class='leftborder'>" + $obj.Path + "</td><td class='leftborder'>" + "{0:N2}" -f ($obj.Size/1024/1024/1024) + "</td><td class='leftborder'>" + "{0:N2}" -f ($obj.FreeSpace/1024/1024/1024) + "</td><td class='leftborder'>" + "{0:N2}" -f ($obj.UsedSpace/1024/1024/1024) + "</td><td class='leftborder'>" 
      if ($obj.PercentFree -le $Threshold) { $Completetable += "<font class='red'>" }	
      elseif ($obj.PercentFree -le ($Threshold + 20)) { $Completetable += "<font class='orange'>" }
      else { $Completetable += "<font class='green'>" }
      $Completetable += "{0:N2}" -f ($obj.PercentFree) + "%</td></tr>"

      if ($obj.PercentFree -le $HIGHPRIO)
	{
	$HighPrioFlag = "high"
	}

      if ($obj.PercentFree -le $Threshold)
	{

	if ($Exclusions -notcontains $obj.Name) 
	  { 
	  #write-host "in : " $obj.Name 
	  $objThreshold += $obj
	  $Threstable += "<tr><td>" + $obj.Name + "</td><td class='leftborder'>" + $obj.Path + "</td><td class='leftborder'>" + "{0:N2}" -f ($obj.Size/1024/1024/1024) + "</td><td class='leftborder'>" + "{0:N2}" -f ($obj.FreeSpace/1024/1024/1024) + "</td><td class='leftborder'>" + "{0:N2}" -f ($obj.UsedSpace/1024/1024/1024) + "</td><td class='leftborder'><font class='red'>" + "{0:N2}" -f ($obj.PercentFree) + "%</td></tr>"
	  $SendMail = $true
	  }
	else #If IN exclusions list, but under HIGHPRIO Threshold, DO include in logging
	  {
	  if ($obj.PercentFree -le $HIGHPRIO)
		{
		$objThreshold += $obj
	  	$Threstable += "<tr><td>" + $obj.Name + "</td><td class='leftborder'>" + $obj.Path + "</td><td class='leftborder'>" + "{0:N2}" -f ($obj.Size/1024/1024/1024) + "</td><td class='leftborder'>" + "{0:N2}" -f ($obj.FreeSpace/1024/1024/1024) + "</td><td class='leftborder'>" + "{0:N2}" -f ($obj.UsedSpace/1024/1024/1024) + "</td><td class='leftborder'><font class='red'>" + "{0:N2}" -f ($obj.PercentFree) + "%</td></tr>"
	  	$SendMail = $true
		}
	  }

	}
   }
}

$Threstable += "</table>"
$Completetable += "</table>"

if ($Logging)
  {
  $objThreshold | ft -auto Name,Path,@{ Label = "Size(GB)" ; Expression = { "{0:N2}" -f ($_.Size/1024/1024/1024) } },@{ Label = "FreeSpace(GB)" ; Expression = { "{0:N2}" -f ($_.FreeSpace/1024/1024/1024) } },@{ Label = "UsedSpace(GB)" ; Expression = { "{0:N2}" -f ($_.UsedSpace/1024/1024/1024) } },@{ Label = "PercentFree" ; Expression = { "{0:N2}" -f ($_.PercentFree) } } 
 }


if ($CompleteLog)
  {
  $objs | ft -auto Name,Path,@{ Label = "Size(GB)" ; Expression = { "{0:N2}" -f ($_.Size/1024/1024/1024) } },@{ Label = "FreeSpace(GB)" ; Expression = { "{0:N2}" -f ($_.FreeSpace/1024/1024/1024) } },@{ Label = "UsedSpace(GB)" ; Expression = { "{0:N2}" -f ($_.UsedSpace/1024/1024/1024) } },@{ Label = "PercentFree" ; Expression = { "{0:N2}" -f ($_.PercentFree) } }
  $Threstable += $Completetable
 }

if ($SendMail) {
if ($MailLog)
	{
	[string]$cluname = Get-WmiObject -class 'mscluster_cluster' -Namespace 'root\mscluster' -ComputerName . | select -ExpandProperty name
	$Subject += " (Cluster Name : $cluname)" 
	send-mailmessage -BodyAsHtml -body $Threstable -subject $Subject -to $mailto -from $From -smtpserver $Smtpserver -Priority $HighPrioFlag
	} #End Send Log
}

}